# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmModelServiceRolloutStepStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'created_revision_number': 'int',
        'last_updated': 'datetime',
        'message': 'str',
        'step_started': 'datetime',
        'step_status': 'str'
    }

    attribute_map = {
        'created_revision_number': 'created_revision_number',
        'last_updated': 'last_updated',
        'message': 'message',
        'step_started': 'step_started',
        'step_status': 'step_status'
    }

    def __init__(self, created_revision_number=None, last_updated=None, message=None, step_started=None, step_status=None, local_vars_configuration=None):  # noqa: E501
        """OrmModelServiceRolloutStepStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._created_revision_number = None
        self._last_updated = None
        self._message = None
        self._step_started = None
        self._step_status = None
        self.discriminator = None

        if created_revision_number is not None:
            self.created_revision_number = created_revision_number
        if last_updated is not None:
            self.last_updated = last_updated
        if message is not None:
            self.message = message
        if step_started is not None:
            self.step_started = step_started
        if step_status is not None:
            self.step_status = step_status

    @property
    def created_revision_number(self):
        """Gets the created_revision_number of this OrmModelServiceRolloutStepStatus.  # noqa: E501


        :return: The created_revision_number of this OrmModelServiceRolloutStepStatus.  # noqa: E501
        :rtype: int
        """
        return self._created_revision_number

    @created_revision_number.setter
    def created_revision_number(self, created_revision_number):
        """Sets the created_revision_number of this OrmModelServiceRolloutStepStatus.


        :param created_revision_number: The created_revision_number of this OrmModelServiceRolloutStepStatus.  # noqa: E501
        :type created_revision_number: int
        """

        self._created_revision_number = created_revision_number

    @property
    def last_updated(self):
        """Gets the last_updated of this OrmModelServiceRolloutStepStatus.  # noqa: E501


        :return: The last_updated of this OrmModelServiceRolloutStepStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._last_updated

    @last_updated.setter
    def last_updated(self, last_updated):
        """Sets the last_updated of this OrmModelServiceRolloutStepStatus.


        :param last_updated: The last_updated of this OrmModelServiceRolloutStepStatus.  # noqa: E501
        :type last_updated: datetime
        """

        self._last_updated = last_updated

    @property
    def message(self):
        """Gets the message of this OrmModelServiceRolloutStepStatus.  # noqa: E501


        :return: The message of this OrmModelServiceRolloutStepStatus.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this OrmModelServiceRolloutStepStatus.


        :param message: The message of this OrmModelServiceRolloutStepStatus.  # noqa: E501
        :type message: str
        """

        self._message = message

    @property
    def step_started(self):
        """Gets the step_started of this OrmModelServiceRolloutStepStatus.  # noqa: E501


        :return: The step_started of this OrmModelServiceRolloutStepStatus.  # noqa: E501
        :rtype: datetime
        """
        return self._step_started

    @step_started.setter
    def step_started(self, step_started):
        """Sets the step_started of this OrmModelServiceRolloutStepStatus.


        :param step_started: The step_started of this OrmModelServiceRolloutStepStatus.  # noqa: E501
        :type step_started: datetime
        """

        self._step_started = step_started

    @property
    def step_status(self):
        """Gets the step_status of this OrmModelServiceRolloutStepStatus.  # noqa: E501


        :return: The step_status of this OrmModelServiceRolloutStepStatus.  # noqa: E501
        :rtype: str
        """
        return self._step_status

    @step_status.setter
    def step_status(self, step_status):
        """Sets the step_status of this OrmModelServiceRolloutStepStatus.


        :param step_status: The step_status of this OrmModelServiceRolloutStepStatus.  # noqa: E501
        :type step_status: str
        """
        allowed_values = ["succeeded", "in_progress", "paused", "failed"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and step_status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `step_status` ({0}), must be one of {1}"  # noqa: E501
                .format(step_status, allowed_values)
            )

        self._step_status = step_status

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmModelServiceRolloutStepStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmModelServiceRolloutStepStatus):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class DashboardFieldRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'display_name': 'str',
        'id': 'int',
        'is_grouped': 'bool',
        'is_hidden': 'bool',
        'is_pinned': 'bool',
        'order': 'int',
        'width': 'int'
    }

    attribute_map = {
        'display_name': 'display_name',
        'id': 'id',
        'is_grouped': 'is_grouped',
        'is_hidden': 'is_hidden',
        'is_pinned': 'is_pinned',
        'order': 'order',
        'width': 'width'
    }

    def __init__(self, display_name=None, id=None, is_grouped=None, is_hidden=None, is_pinned=None, order=None, width=None, local_vars_configuration=None):  # noqa: E501
        """DashboardFieldRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._display_name = None
        self._id = None
        self._is_grouped = None
        self._is_hidden = None
        self._is_pinned = None
        self._order = None
        self._width = None
        self.discriminator = None

        if display_name is not None:
            self.display_name = display_name
        self.id = id
        self.is_grouped = is_grouped
        self.is_hidden = is_hidden
        self.is_pinned = is_pinned
        self.order = order
        self.width = width

    @property
    def display_name(self):
        """Gets the display_name of this DashboardFieldRequest.  # noqa: E501


        :return: The display_name of this DashboardFieldRequest.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this DashboardFieldRequest.


        :param display_name: The display_name of this DashboardFieldRequest.  # noqa: E501
        :type display_name: str
        """
        if (self.local_vars_configuration.client_side_validation and
                display_name is not None and len(display_name) > 255):
            raise ValueError("Invalid value for `display_name`, length must be less than or equal to `255`")  # noqa: E501

        self._display_name = display_name

    @property
    def id(self):
        """Gets the id of this DashboardFieldRequest.  # noqa: E501


        :return: The id of this DashboardFieldRequest.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DashboardFieldRequest.


        :param id: The id of this DashboardFieldRequest.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def is_grouped(self):
        """Gets the is_grouped of this DashboardFieldRequest.  # noqa: E501


        :return: The is_grouped of this DashboardFieldRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_grouped

    @is_grouped.setter
    def is_grouped(self, is_grouped):
        """Sets the is_grouped of this DashboardFieldRequest.


        :param is_grouped: The is_grouped of this DashboardFieldRequest.  # noqa: E501
        :type is_grouped: bool
        """

        self._is_grouped = is_grouped

    @property
    def is_hidden(self):
        """Gets the is_hidden of this DashboardFieldRequest.  # noqa: E501


        :return: The is_hidden of this DashboardFieldRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_hidden

    @is_hidden.setter
    def is_hidden(self, is_hidden):
        """Sets the is_hidden of this DashboardFieldRequest.


        :param is_hidden: The is_hidden of this DashboardFieldRequest.  # noqa: E501
        :type is_hidden: bool
        """

        self._is_hidden = is_hidden

    @property
    def is_pinned(self):
        """Gets the is_pinned of this DashboardFieldRequest.  # noqa: E501


        :return: The is_pinned of this DashboardFieldRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_pinned

    @is_pinned.setter
    def is_pinned(self, is_pinned):
        """Sets the is_pinned of this DashboardFieldRequest.


        :param is_pinned: The is_pinned of this DashboardFieldRequest.  # noqa: E501
        :type is_pinned: bool
        """

        self._is_pinned = is_pinned

    @property
    def order(self):
        """Gets the order of this DashboardFieldRequest.  # noqa: E501


        :return: The order of this DashboardFieldRequest.  # noqa: E501
        :rtype: int
        """
        return self._order

    @order.setter
    def order(self, order):
        """Sets the order of this DashboardFieldRequest.


        :param order: The order of this DashboardFieldRequest.  # noqa: E501
        :type order: int
        """
        if (self.local_vars_configuration.client_side_validation and
                order is not None and order < 1):  # noqa: E501
            raise ValueError("Invalid value for `order`, must be a value greater than or equal to `1`")  # noqa: E501

        self._order = order

    @property
    def width(self):
        """Gets the width of this DashboardFieldRequest.  # noqa: E501


        :return: The width of this DashboardFieldRequest.  # noqa: E501
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this DashboardFieldRequest.


        :param width: The width of this DashboardFieldRequest.  # noqa: E501
        :type width: int
        """
        if (self.local_vars_configuration.client_side_validation and
                width is not None and width < 1):  # noqa: E501
            raise ValueError("Invalid value for `width`, must be a value greater than or equal to `1`")  # noqa: E501

        self._width = width

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DashboardFieldRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DashboardFieldRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'max_replica': 'int',
        'min_replica': 'int',
        'revision': 'OrmModelServiceRolloutRevisionReference',
        'running': 'bool'
    }

    attribute_map = {
        'max_replica': 'max_replica',
        'min_replica': 'min_replica',
        'revision': 'revision',
        'running': 'running'
    }

    def __init__(self, max_replica=None, min_replica=None, revision=None, running=None, local_vars_configuration=None):  # noqa: E501
        """OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._max_replica = None
        self._min_replica = None
        self._revision = None
        self._running = None
        self.discriminator = None

        if max_replica is not None:
            self.max_replica = max_replica
        if min_replica is not None:
            self.min_replica = min_replica
        self.revision = revision
        if running is not None:
            self.running = running

    @property
    def max_replica(self):
        """Gets the max_replica of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.  # noqa: E501


        :return: The max_replica of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.  # noqa: E501
        :rtype: int
        """
        return self._max_replica

    @max_replica.setter
    def max_replica(self, max_replica):
        """Sets the max_replica of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.


        :param max_replica: The max_replica of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.  # noqa: E501
        :type max_replica: int
        """

        self._max_replica = max_replica

    @property
    def min_replica(self):
        """Gets the min_replica of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.  # noqa: E501


        :return: The min_replica of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.  # noqa: E501
        :rtype: int
        """
        return self._min_replica

    @min_replica.setter
    def min_replica(self, min_replica):
        """Sets the min_replica of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.


        :param min_replica: The min_replica of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.  # noqa: E501
        :type min_replica: int
        """

        self._min_replica = min_replica

    @property
    def revision(self):
        """Gets the revision of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.  # noqa: E501


        :return: The revision of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.  # noqa: E501
        :rtype: OrmModelServiceRolloutRevisionReference
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """Sets the revision of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.


        :param revision: The revision of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.  # noqa: E501
        :type revision: OrmModelServiceRolloutRevisionReference
        """
        if self.local_vars_configuration.client_side_validation and revision is None:  # noqa: E501
            raise ValueError("Invalid value for `revision`, must not be `None`")  # noqa: E501

        self._revision = revision

    @property
    def running(self):
        """Gets the running of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.  # noqa: E501


        :return: The running of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.  # noqa: E501
        :rtype: bool
        """
        return self._running

    @running.setter
    def running(self, running):
        """Sets the running of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.


        :param running: The running of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.  # noqa: E501
        :type running: bool
        """

        self._running = running

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget):
            return True

        return self.to_dict() != other.to_dict()
